# Python Poetry Tutorial

![Python](https://img.shields.io/badge/Python-v3.8-blue.svg?logo=python&longCache=true&logoColor=white&colorB=5e81ac&style=flat-square&colorA=4c566a)
![Psutil](https://img.shields.io/badge/psutil-v5.6.7-blue.svg?longCache=true&logo=python&style=flat-square&logoColor=white&colorB=5e81ac&colorA=4c566a)
![Loguru](https://img.shields.io/badge/Loguru-v0.4.1-blue.svg?longCache=true&logo=python&style=flat-square&logoColor=white&colorB=5e81ac&colorA=4c566a)
![GitHub Last Commit](https://img.shields.io/github/last-commit/google/skia.svg?style=flat-square&colorA=4c566a&colorB=a3be8c&logo=GitHub)
[![GitHub Issues](https://img.shields.io/github/issues/hackersandslackers/python-poetry-tutorial.svg?style=flat-square&colorA=4c566a&logo=GitHub&colorB=ebcb8b)](https://github.com/hackersandslackers/python-poetry-tutorial/issues)
[![GitHub Stars](https://img.shields.io/github/stars/hackersandslackers/python-poetry-tutorial.svg?style=flat-square&colorA=4c566a&logo=GitHub&colorB=ebcb8b)](https://github.com/hackersandslackers/python-poetry-tutorial/stargazers)
[![GitHub Forks](https://img.shields.io/github/forks/hackersandslackers/python-poetry-tutorial.svg?style=flat-square&colorA=4c566a&logo=GitHub&colorB=ebcb8b)](https://github.com/hackersandslackers/python-poetry-tutorial/network)

![Poetry](poetry_tutorial_project/static/social.jpg)

## Getting Started

Run the following to install and launch the demo app using [Poetry](https://python-poetry.org/):

```shell
$ git clone https://github.com/hackersandslackers/python-poetry-tutorial.git
$ cd python-poetry-tutorial
$ poetry shell
$ poetry install
$ poetry run
```

-----

**Hackers and Slackers** tutorials are free of charge. If you found this tutorial helpful, a [small donation](https://www.buymeacoffee.com/hackersslackers) would be greatly appreciated to keep us in business. All proceeds go towards coffee, and all coffee goes towards more content.
